@@ -26,6 +26,8 @@ Created on 30 Mar 2020
 import wtforms.fields.html5 as fields5
 import wtforms as fields
 import wtforms.validators as validator
+import flask_table as ft
+
 
 WTF_FIELDS_ATTRIBUTES = ['label',       #– The label of the field.
                          'validators',  # – A sequence of validators to call when validate is called.
@@ -55,7 +57,9 @@ WTF_TRYTON_FIELD_ATTRIBUTES_MAPPING = {'name': 'id',
                                        #'required': '',
                                        'help': 'description',
                                        'string':'label'}
+
 WTF_TRYTON_FIELD_ATTRIBUTES_SPECIFIC = {'selection': {'select': 'choices'}}
+
 WTF_TRYTON_FIELD_MAPPING = {'boolean': fields.BooleanField,
                             'integer':fields.IntegerField,
                             'biginteger':fields.IntegerField,
@@ -81,3 +85,18 @@ WTF_TRYTON_FIELD_MAPPING = {'boolean': fields.BooleanField,
                             #dict
                             }
 
+
+FT_TRYTON_FIELD_ATTRIBUTE_MAPPING = {
+                    'integer': ft.Col,
+                    'char': ft.Col,
+                    'text': ft.Col,
+                    'selection': ft.Col,
+                    'biginteger': ft.Col,
+                    'optcol': ft.OptCol,           # Converts values according to a dictionary of choices. Eg for turning stored codes into human readable text.
+                    'boolean': ft.BoolNaCol,    # BoolNaCol (subclass of BoolCol) - converts values to yes/no/na
+                    'date': ft.DateCol,         # For dates (uses format_date from babel.dates).
+                    'datetime': ft.DatetimeCol, # For date-times (uses format_datetime from babel.dates).
+                    'link':ft.LinkCol,             # Creates a link by specifying an endpoint and url_kwargs.
+                    'button': ft.ButtonCol,     # (subclass of LinkCol) creates a button that posts the the given address.
+                    'many2many': ft.NestedTableCol # Allows nesting of tables inside columns
+                    }
